function foil = create_motionRAO(foil,vessel)

freqs  = vessel.freqs;
heads  = vessel.headings;
vels   = vessel.velocities;

nfreqs = length(freqs);
nheads = length(heads);
nvels  = length(vels);
ndof   = 6;

g = vessel.main.g;

M = vessel.M + foil.M;
A = vessel.A + foil.A;
B = vessel.B + foil.B;
C = vessel.C + foil.C;
F = vessel.forceRAO.complex + foil.F;

eigen = zeros(2*ndof,1);


for j = 1:nvels;
 
    U = vels(j);
    
    for h = 1:nheads,
 
        Beta = heads(h);

        for i = 1:nfreqs;
            
            w   = freqs(i);
            k   = w^2/g;
            w_e = w + k*U*cos(Beta); 

            % State space representation
            % -------------------------------------------------------------
            m = M(:,:);
            a = A(:,:,i,h,j);
            b = B(:,:,i,h,j);
            c = C(:,:,i,h,j);
            f = F(:,:,i,h,j);

            Ass = [zeros(ndof) eye(ndof);
                   -(m+a)\c   -(m+a)\b ]; 
            Bss = [zeros(ndof,1);
                      (m+a)\f  ];
            Css = [eye(ndof) zeros(ndof)];                 
            Dss = 0;
                      
            % State-space system and transfer function
            SSsys = ss(Ass,Bss,Css,Dss);        
            TFsys = tf(SSsys);
            eigen(:,i,h,j) = eig(Ass);
            
            % Frequency-response vector
            Hss  = freqresp(TFsys,w_e);
                                   
            % Fourier transfer function 
            % -------------------------------------------------------------
            % Encounter frequency as input - wave frequency as x-axis
           
            H = (-(m+a)*w_e^2 + b*1i*w_e + c)\f;
            
            for l = 1:ndof;
                
                foil.motionRAO.Hss.complex{l}(i,h,j) = Hss(l);
                foil.motionRAO.Hss.amp{l}(i,h,j)     = abs(Hss(l));
                foil.motionRAO.Hss.phase{l}(i,h,j)   = angle(Hss(l));
                
                foil.motionRAO.H.complex{l}(i,h,j) = H(l);
                foil.motionRAO.H.amp{l}(i,h,j)     = abs(H(l));
                foil.motionRAO.H.phase{l}(i,h,j)   = angle(H(l));
            end
           
        end
    end
end

% Saving history of eigenvalues for transfer-functions
foil.motionRAO.eigen = eigen; 














