function foil = foilChar(foil)

rho  = foil.main.rho;

span = foil.main.span;
cord = foil.main.cord;
xCO  = foil.main.xCO;

S    = cord*span;
AR   = span^2/S;

% Checking if CL is already defined as numeric value
if isfield(foil.main,'CL')       
else 
    CL = 2*pi/(1 + 2/AR);
    foil.main.CL     =  CL;
end

% Naming file
filename = 'Files/naca0015.dat';

if ~exist(filename,'file');
    disp('Naca-0015 specification-file not found')
    disp('Mass of foil is estimated from surface area')
    
    % Estimating mass of foil
    m = S*0.5*rho;

else
    
    % Open Naca-0015 file displaying coordinates
    fid  = fopen(filename);
  
    name        = fgets(fid);       % Name of file (header)
    str = sprintf('Reading file: %s',name);
    disp(str);
    ncoord      = 35;                    % Number of coordinates
    [pos thick] = deal(zeros(ncoord,1)); % Preallocating for speed
  
    for i = 1:ncoord;                   % Looping coordinates

        read    = fscanf(fid,'%f',2);   % Reading file
        pos(i)  = read(1);              % Position  (x-value in gen. coord 
                                        % -> x-value range: 0-1)
        thick(i)= read(2);              % Thickness (y-value in gen. coord)
    
    end
    
    % From generalized coordinates to actual
    pos   = pos*cord;
    thick = thick*cord;

    % Initial values
    dV = 0;     % Volume of foil
    dS = 0;     % Surface area of foil

    % Estimating total volume and surface-area of foil.
    for i = 1:ncoord-1;

        dl  = abs(pos(i+1)-pos(i));
        dV  = dV + dl*abs((thick(i+1)+thick(i)))/2;
        dS  = dS + sqrt(dl^2+(thick(i+1)-thick(i))^2);
    end
    
    % Defining mass, 3D-surface-area and Moment of inertia of foil
    % The mass is defined by allowing the foil zero bouyancy in water.
    m   = dV*span*rho;
    S3D = dS*span;    
  
end

% Mass-matrix
I   = m*(cord/2)^2/12 + m*xCO^2; 
M   = diag([m m m 0 I 0]); % Only inertia in pitch is found!


foil.main.S      =  S;
foil.main.S3D    =  S3D;
foil.main.AR     =  AR;
foil.main.rho    =  rho;
foil.main.I      =  I;
foil.M           =  M;






