

% Experimental data Heave RAO
w_set = 2*pi./T_set;

% HEAVE RAOs ---
% Without foil
rao8    = [0.8538,0.8101,0.6637,0.6411,0.6743,0.2519];
rao10   = [0.8991,0.8659,0.7844,0.7678,0.6351,0.1584];
rao12   = [0.9594,0.9428,0.9368,0.8930,0.6366,0.1569];
exRAOh  = [rao8' rao10' rao12'];

% With foil
rao8f   = [0.8666,0.8590,0.6506,0.5290,0.2597,0.1214];
rao10f  = [0.9129,0.8645,0.7264,0.5201,0.2285,0.1000];
rao12f  = [0.9575,0.8989,0.7431,0.5163,0.2494,0.1110];
exRAOhf = [rao8f' rao10f' rao12f'];

% PITCH RAOs ---
% Without foil
rao8p   = [1.6818,1.9901,2.4950,2.4573,2.6310,1.0176];
rao10p  = [1.7213,2.0602,2.3469,2.6745,2.4833,0.7217];
rao12p  = [1.8160,2.1917,2.5121,2.7853,2.3813,0.6542];
exRAOp  = [rao8p' rao10p' rao12p'];
% With foil
rao8pf  = [1.4183,1.4890,1.6573,1.6553,1.3198,0.4500];
rao10pf = [1.3870,1.5493,1.5494,1.5200,1.2323,0.3526];
rao12pf = [1.3732,1.5112,1.5725,1.5253,1.1971,0.3421];
exRAOpf = [rao8pf' rao10pf' rao12pf'];

w     = vessel.freqs;
vels  = vessel.velocities;
heads = vessel.headings;

nBeta = length(Beta_set);
nU    = length(U_set);
nT    = length(T_set);

rad2deg = 180/pi;
ms2kn   = 1/0.5144;

for i = 1:nU
    
    U         = U_set(i);
    [~,U_idx] = min(abs(vels-U));  % Finding index for setpoint velocity 
    
    
    %for j = 1:nBeta  
        
        %Beta      = Beta_set(j);
        %[~,B_idx] = min(abs(heads-Beta));  % Finding index for setpoint heading 
        
        % Beta Fossen (MSS): B_idx  = 19
        B_idxMSS = 19;
        % Beta Faltinsen (VERES): B_idx  = 1;
        B_idx = 1;
        
        
        load(file_wFoil);
        load(file_wFoilABC); 
        figure(80 + i);
        hold on
        veresRAO   = vessel.motionRAO.amp{3}(:,B_idxMSS,U_idx);
        ssRAO      = foil.motionRAO.Hss.amp{3}(:,B_idx,i);
        frespRAO   = foil.motionRAO.H.amp{3}(:,B_idx,i);
        tsRAOwFoil = output_wFoil(4,:,B_idx,i);
        tsRAOwcFoil= output_wcFoil(4,:,B_idx,i);
        tsRAOwsFoil= output_wsFoil(4,:,B_idx,i);
        exRAOwFoil = exRAOhf(:,i);  % Beta = 0;

        plot(w,veresRAO,'k',w,ssRAO,'xk',w,frespRAO,'+k');
        plot(w_set,tsRAOwFoil,'o-k',w_set,exRAOwFoil,'*-k');
        plot(w_set,tsRAOwcFoil,'r',w_set,tsRAOwsFoil,'g');
        
        load(file_woFoil);
        load(file_woFoilABC);
        
        veresRAO    = vessel.motionRAO.amp{3}(:,B_idxMSS,U_idx);
        tsRAOwoFoil = output_woFoil(4,:,B_idx,i);
        exRAOwoFoil = exRAOh(:,i);  % Beta = 0;

        plot(w,veresRAO,'--k');
        plot(w_set,tsRAOwoFoil,'o--k',w_set,exRAOwoFoil,'*--k');
                
        title(strcat('Heave motion of vessel at ',num2str(U*ms2kn),' knots'))
        xlabel('Wave frequency [1/s]')
        ylabel('Heave RAO [-]')
        legend('Foil: Freq-dom VERES calculation',...
            'Foil: Freq-dom state-space formulation',...
            'Foil: Freq-dom frequency-response',...
            'Foil: Time-dom. frequency response',...
            'Foil: Time-dom experimental results',...
            'Controlled foil: Time-domain',...
            'Spring-loaded foil: Time-domain',...
            'No foil: Freq-dom VERES calculation',...
            'No foil: Time-dom. frequency response',...
            'No foil: Time-dom experimental results');
        
        hold off
        
        
        
        load(file_wFoil);
        load(file_wFoilABC); 
        
        figure(90 + i);
        hold on
        veresRAO   = vessel.motionRAO.amp{5}(:,B_idxMSS,U_idx)*rad2deg;
        ssRAO      = foil.motionRAO.Hss.amp{5}(:,B_idx,i)*rad2deg;
        frespRAO   = foil.motionRAO.H.amp{5}(:,B_idx,i)*rad2deg;
        tsRAOwFoil = output_wFoil(5,:,B_idx,i);
        tsRAOwcFoil= output_wcFoil(5,:,B_idx,i);
        tsRAOwsFoil= output_wsFoil(5,:,B_idx,i);
        exRAOwFoil = exRAOpf(:,i);  % Beta = 0;

        plot(w,veresRAO,'k',w,ssRAO,'xk',w,frespRAO,'+k');
        plot(w_set,tsRAOwFoil,'o-k',w_set,exRAOwFoil,'*-k');
        plot(w_set,tsRAOwcFoil,'r',w_set,tsRAOwsFoil,'g');
        
        load(file_woFoil);
        load(file_woFoilABC);
        
        veresRAO    = vessel.motionRAO.amp{5}(:,B_idxMSS,U_idx)*rad2deg;
        tsRAOwoFoil = output_woFoil(5,:,B_idx,i);
        exRAOwoFoil = exRAOp(:,i);  % Beta = 0;
        
        
        plot(w,veresRAO,'--k');
        plot(w_set,tsRAOwoFoil,'o--k',w_set,exRAOwoFoil,'*--k');
        
        title(strcat('Pitch motion of vessel at ',num2str(U*ms2kn),' knots'))
        xlabel('Wave frequency [1/s]')
        ylabel('Pitch RAO [deg]')
        legend('Foil: Freq-dom VERES calculation',...
            'Foil: Freq-dom state-space formulation',...
            'Foil: Freq-dom frequency-response',...
            'Foil: Time-dom. frequency response',...
            'Foil: Time-dom experimental results',...
            'Controlled foil: Time-domain',...
            'Spring-loaded foil: Time-domain',...
            'No foil: Freq-dom VERES calculation',...
            'No foil: Time-dom. frequency response',...
            'No foil: Time-dom experimental results');
        
        
        hold off
        
        
        

    %end
end

           
