function [] = postMC(foil,input,plot_flag)

% Post-processing folder for MC-lab experiments
folder ='C:\Users\Fridtjof\Dropbox\Masteroppgave\Master\Forsk\Results from experiments in MC lab\Eirik\Data\';

% Post-porcessing path for MC-lab experiments
switch input
    case 1 
        U  = 1.286; T = 1.75;  % eta5_a = 0; eta3_a = 0.03; 
        path   ='16 Januar\dynamic_1d286_0_0d03_1d75';
    case 2 
        U  = 1.286; T = 2.25;  % eta5_a = 0; eta3_a = 0.04; 
        path   ='16 Januar\dynamic_1d286_0_0d04_2d25';
    case 3 
        U  = 1.286; T = 2.125; % eta5_a = 0; eta3_a = 0.04;
        path   ='16 Januar\dynamic_1d286_0_0d04_2d125';
    case 4 
        U  = 1.286; T = 2.375; % eta5_a = 0; eta3_a = 0.04;  
        path   ='16 Januar\dynamic_1d286_0_0d04_2d375';
    case 5 
        U  = 1.286; T = 1.75;  % eta5_a = 0; eta3_a = 0.05;  
        path   ='16 Januar\dynamic_1d286_0_0d05_1d75';
    case 6 
        U  = 1.286; T = 2.25;  % eta5_a = 0; eta3_a = 0.0886; 
        path   ='16 Januar\dynamic_1d286_0_0d0886_2d25';
    case 7 
        U  = 1.286; T = 2.125; % eta5_a = 0; eta3_a = 0.0886; 
        path   ='16 Januar\dynamic_1d286_0_0d0886_2d125';
    case 8 
        U  = 1.286; T = 2.375; % eta5_a = 0; eta3_a = 0.0886;
        path   ='16 Januar\dynamic_1d286_0_0d0886_2d375';
    case 9 
        U  = 1.286; T = 2.25;  % eta5_a = 0; eta3_a = 0.12;
        path   ='16 Januar\dynamic_1d286_0_0d12_2d25';
    case 10 
        U  = 1.286; T = 2.125; % eta5_a = 0; eta3_a = 0.12;
        path   ='16 Januar\dynamic_1d286_0_0d12_2d125';
    case 11 
        U  = 1.286; T = 2.375; % eta5_a = 0; eta3_a = 0.12;
        path   ='16 Januar\dynamic_1d286_0_0d12_2d375';
    case 12 
        U  = 1.286; T = 2.25;  % eta5_a = 0; eta3_a = 0.135;
        path   ='16 Januar\dynamic_1d286_0_0d135_2d25';
    case 13 
        U  = 1.286; T = 2.125; % eta5_a = 0; eta3_a = 0.135; 
        path   ='16 Januar\dynamic_1d286_0_0d135_2d125';
    case 14 
        U  = 1.286; T = 2.375; % eta5_a = 0; eta3_a = 0.135;
        path   ='16 Januar\dynamic_1d286_0_0d135_2d375';
end

% Checking if file exist
filename = [folder path '.bin'];
if ~exist(filename,'file')
    disp(' ... File non-existent, please check filename ... ')
    return
end

if ~exist('plot_flag','var')
    plot_flag = '000';
end


% Reading file and saving to structs 
[struct1,struct2] = catman_read(filename);

% Loading file information from struct 
nchan = struct1.noofchan;                       % Number of channels
ntime = min(length(struct2(1).data),2400000);   % Number of timesteps
data  = zeros(ntime,nchan);
for i = 1:nchan;
    data(:,i) = struct2(i).data;
end

% Valid key channel information (columns in 'data')
% 1.    Time
% 2.    Vertical force front left
% 3.    Vertical force back
% 4.    Vertical force front right
% 5.    Horizontal force
% 8.    Pressure at sensor 2 [kPa]
% 9.    Pressure at sensor 4 [kPa]
% 10.   Pressure at sensor 1 [kPa]
% 11.   Pressure at sensor 5 [kPa]
% 12.   Pressure at sensor 3 [kPa]
% 13.   Horizontal position of carriage
% 14.   Vertical position of heave actuators (positive direction downward)
% 15.   Foil angle 
% 16.   Wave height at 0.25*c from leading edge


% Calibration factors for experiments 
data(:,2) = 0.91523057*data(:,2);   
data(:,3) = 1.17059392*data(:,3);   
data(:,4) = 0.79170728*data(:,4);  

% Thrust
thrust = data(:,5);
thrust = lpfilter(thrust);

% Foil characteristic variables for model
rho      = foil.MClab.rho;
%g        = foil.main.g;
scale    = foil.MClab.scale;
cord     = foil.main.cord/scale;
span     = foil.main.span/scale;
CL_foil  = foil.main.CL;
S        = foil.main.S/scale^2;     % Surface area of foil   
deg2rad  = pi/180;

w   = 2*pi/T;                   % Heaving frequency
%w_e = w + w^2/g*U;             % Encounter frequency
               
[C,kf]   = theodorsen(cord,U,w);  % Theodorsen and reduced frequency [-]
                                 
AmpC = abs(C);                    % Amplitude reduction
PhsC = angle(C);                  % Phase-delay
Tau = PhsC/(2*pi);                % Non-dimensional time-delay from phase 


%% Calculates lift from data series from force equilibrium
L  = sum(data(:,2:4),2);
CL = L/(0.5*U^2*rho*S);


%% Estimates effective angle of attack and lift from pressure detection
% Cp defined from pressure experiments
% Cp51 = (p5-p1)/(0.5*U^2*rho)*1000 - made dimensionless in Pa
syms Cp x 

alpha   = solve('Cp = 0.0256*x - 0.0542');
p5minp1 = data(:,11) - data(:,10);
Cp51    = p5minp1./(0.5*U^2*rho).*1000;

% Finds alpha in any timestep from pressure, AoAp [deg]
AoAp = -subs(alpha,Cp,Cp51);         % Effective angle of attack
%CLp  =  CLgen(AoAp);                 % Runs CL-generator (static)
%Lp   =  CLp.*(0.5*U^2*rho*S);        % Instantaneous lift  

CLp_dyn   = AoAp*deg2rad*CL_foil;   % Dynamic linear estimate        
Lp_dyn    = CLp_dyn*(0.5*U^2*rho*S); 


%% Estimate angle of attack and thus lift from carriage motion
% AoAw = (w_wave - eta3dot + eta5dot*x)/U + delta;
% w_wave = 0; eta5dot = 0; delta = 0;
time  = data(:,1);
t_tot = data(ntime,1);
dt    = t_tot/ntime;
                                                              
eta3dot = diff(data(:,14))./dt;             % Finding eta3dot from position 
eta3dot = lpfilter(eta3dot);                % Filtering signal with zero-phase
eta3dot(ntime) = eta3dot(length(eta3dot));  % Adjusting for lost values from diff.

% Angle of attack from motion of carriage, AoAw [deg] and lift
AoAr = -eta3dot./U/deg2rad;            
AoAw = AoAr*AmpC;                           % Adjusted for Theodorsen (unsteady)
                                            % Does not inlcude phase-shift
U_rel= sqrt(eta3dot.^2+U^2);
CLw  = CLgen(AoAw);                         % Runs CL-generator (static CL)
Lw   = CLw.*(0.5*U_rel.^2*rho*S);            % Instantaneous lift

                                            
CLw_dyn   = AoAw*deg2rad*CL_foil;           % Dynamic linear estimate   
Lw_dyn    = CLw_dyn.*(0.5*U_rel.^2*rho*S);

% Thrust
CL_relvel   = CLw_dyn;
CD_relvel   = 0.0005.*AoAw.^2 + 0.015;

L = CL_relvel.*(0.5.*U_rel.^2.*rho.*S);
D = CD_relvel.*(0.5.*U_rel.^2.*rho.*S);

N_force = L.*cos(AoAw*deg2rad) + D.*sin(AoAw*deg2rad);
T_force = L.*sin(AoAw*deg2rad) - D.*cos(AoAw*deg2rad);

%% Estimating added mass (inertial) force
% acc_rel = (wdot_wave - eta3ddot + eta5ddot*x)/U 

eta3ddot   = diff(eta3dot)./dt;                 % Finding eta3ddot from velocity
eta3ddot   = lpfilter(eta3ddot);                % Filtering signal with zero-phase
eta3ddot(ntime)  = eta3ddot(length(eta3ddot));  % Adjusting for lost values from diff.

Fa = rho*pi*(cord/2)^2*span*eta3ddot;           % Inertia force
Ca = Fa./(0.5*U_rel.^2*rho*S);                        % Make comparison with CL possible


%% Plotting
% Defining one period oscillation
t_start = 11.7;                   % Start of oscillation. Arbitrary
nstart  = floor(t_start/dt);      % Start element number
nend    = floor((t_start + 2*T)/dt);

if strcmp(plot_flag(1),'1');
    
    figure(10+input);
%     subplot(2,1,1)
%     hold on
%     title(strcat('LIFT FORCES. Filename:', path))
%     plot(time,L,'b',time,Lp_dyn,':r',time,Lw_dyn,'--g',time,Lw,'-.k');
%     legend('From force equil.','From pressure','From relative vel. ',...
%         'From relative vel. (Non-linear CL)');
%     xlabel('Time [s]');
%     ylabel('Force [N]');
%     hold off
%     
%     subplot(2,1,2)
    hold on
    title(strcat('LIFT FORCES (Zoom). Filename:', path))
    plot(time(nstart:nend),L(nstart:nend),'b',time(nstart:nend),...
        Lp_dyn(nstart:nend),'r',time(nstart:nend),Lw_dyn(nstart:nend),...
        'g',time(nstart:nend),Lw(nstart:nend),'k');
    legend('From force equil.','From pressure','From relative vel.',...
        'From relative vel. (Nonlinear CL)');
    xlabel('Time [s]');
    ylabel('Force [N]'); 
    hold off
    
    figure(20+input);
    hold on
    title(strcat('Thrust. Filename:', path))
    plot(time(nstart:nend),thrust(nstart:nend),'r',...
        time(nstart:nend),T_force(nstart:nend),'b');
    legend('From force equil.','From relative vel.');
    xlabel('Time [s]');
    ylabel('Thrust [N]'); 
    hold off
    
end

% title(strcat('LIFT FORCES based on static non-linear CL. Filename: ', path))
% plot(time,L,time,Lp,'g',time,Lw,'r');
% legend('From force equil.','From pressure','From relative vel.');
% xlabel('Time [s]');
% ylabel('Force [N]');

% figure(12+input);
% title(strcat('Lift force versus Inertia force. Filename: ', path))
% plot(time,L,time,Fw,'g',time,Lw_dyn,'r');
% legend('Force from force equil.','Inertia force from rel. vel.','Lift force from rel. vel.');
% xlabel('Time [s]');
% ylabel('Force [N]');



if strcmp(plot_flag(2),'1');

    figure(11+input);
    
%     subplot(2,1,1);
%     hold on
%     title(strcat('Angle of attack. Filename: ', path))
%     plot(time,AoAp,'b',time,AoAr,':r',time,AoAw,'--k');
%     legend('From pressure','From relative vel (w/o Theodorsen)',...
%         'From relative vel ');
%     xlabel('Time [s]');
%     ylabel('Degrees [deg]');
%     hold off
%     
%     subplot(2,1,2);
    hold on
    title(strcat('Angle of attack (zoom). Filename: ', path))
    plot(time(nstart:nend),AoAp(nstart:nend),'b',time(nstart:nend),...
        AoAr(nstart:nend),'r',time(nstart:nend),AoAw(nstart:nend),...
        'g');
    legend('From pressure','From relative vel (w/o Theodorsen)','From relative vel ');
    xlabel('Time [s]');
    ylabel('Degrees [deg]')
    %annotation('textbox',[0.2 0.52 -0.5 -0.5],'String',...
        %strcat('Theodorsen:  Amp(C(kf=',num2str(kf),')):  ',num2str(AmpC),',  Angle(C(kf)): ',...
        %num2str(PhsC), ',  Tau = ',num2str(Tau),'*T'),'FitBoxToText','on');
    hold off
    
end

if strcmp(plot_flag(3),'1');

    figure(12+input);
    subplot(2,1,1);
    hold on
    title(strcat('AoA, CL and Added mass coeff (F_added/(0.5*U^2*rho*S)). Filename: ', path))
    plot(time(nstart:nend),CL(nstart:nend),'b',time(nstart:nend),...
        AoAw(nstart:nend)*deg2rad,'r',time(nstart:nend),...
        Ca(nstart:nend),'g');
    legend('Lift coefficient from force equil.',...
        'Angle of attack from rel. vel ',...
        'Added mass variable, Ca = F_added/(0.5*U^2*rho*S)');
    xlabel('Time [s]');
    ylabel('[-]');
    hold off
    
    subplot(2,1,2);
    hold on
    title(strcat('Hysterisis-plot of CL vs AoA. Filename: ', path))
    scatter(AoAr(nstart:nend),CL(nstart:nend),2.1,'k')
    %plot(AoAp(nstart:nend),CL(nstart:nend),'k','LineWidth',0.5)
    legend('Angle of attack from rel.vel.');%,'Angle of attack from pressure.');
    grid
    xlabel('Angle of attack [deg]');
    ylabel('Lift coefficient [-]')
    hold off
    
end

































    
    










