
function [] = postSlepetanken(foil,folder,path)

filename = [folder path '.bin'];
if (~exist(filename,'file'))
    disp(' ... File non-existent, please check filename ... ')
    return
end
disp('... Loading data ...')
[a1,a2] = catman_read_5r8(filename);

% Arrange data:
nochan     = 40; % number of channels 
nochan_pos = 6; % number of channels for position measurements except time
ntime      = length(a2(2).data); % number of timesteps
ntime_pos  = length(a2(1).data); % number of timesteps for the position measurements

% Time
time  = a2(2).data;
t_tot = time(ntime);
dt    = t_tot/ntime;

deg2rad  = pi/180;

% Reading from file-matrix
format short
resistance = a2(39).data;
thrust     = a2(35).data; 
speed      = a2(22).data;
lift       = a2(40).data;
aoaest     = -a2(27).data;
wave       = a2(38).data;
heave      = a2(24).data/1000;
pitch      = a2(23).data*deg2rad;
p5         = a2(20).data;
p1         = a2(19).data;

% Foil characteristic variables for model
rho      = foil.MClab.rho;
g        = foil.main.g;
scale    = foil.MClab.scale;
cord     = foil.main.cord/scale;
span     = foil.main.span/scale;
CL_foil  = foil.main.CL;
S        = foil.main.S/scale^2;    % Surface area of foil   
T        = 7.5/sqrt(scale);
U        = 1.286;
xf       = -foil.main.xf/scale;    % Positive axis fwd
zf       = foil.main.zf/scale;

w   = 2*pi/T;                      % Heaving frequency
w_e = w + w.^2./g.*speed;          % Encounter frequency
k   = w^2/g;

[AmpC,PhsC] = deal(zeros(1,ntime));
[AmpS,PhsS] = deal(zeros(1,ntime));

for i = 1:ntime;
    U = speed(i);
    [C,kf,Sear]   = theodorsen(cord,U,w);  % Theodorsen and reduced frequency [-]
                                 
    AmpC(i) = abs(C);                    % Amplitude reduction Theodorsen
    PhsC(i) = angle(C);                  % Phase-delay Theodorsen
    AmpS(i) = abs(Sear);                    % Amplitude reduction Sears
    PhsS(i) = angle(Sear);                  % Phase-delay Sears
    
end
    

%% Calculates lift from data series from force equilibrium
CL = lift./(0.5.*speed.^2.*rho.*S);

%% Estimate angle of attack and thus lift from carriage motion
% AoAw = (w_wave - eta3dot + eta5dot*x)/U + delta;
% w_wave = 0; eta5dot = 0; delta = 0;
                                                              
eta3dot = diff(heave)./dt;                  % Finding eta3dot from position 
eta3dot = lpfilter(eta3dot);                % Filtering signal with zero-phase
eta3dot(ntime) = eta3dot(length(eta3dot));  % Adjusting for lost values from diff.

eta5dot = diff(pitch)./dt;                  % Finding eta3dot from position 
eta5dot = lpfilter(eta5dot);                % Filtering signal with zero-phase
eta5dot(ntime) = eta3dot(length(eta5dot));  % Adjusting for lost values from diff.

% Phase shift for wave velocity from wave motion
wave_pos = -4.7;                         % Position of wave-measurement from foil
time_phs = (pi/2+k.*wave_pos+PhsS)./w_e; % pi/2 - 90deg phase shift and position phase - time lag
nlag     = -time_phs./dt;                % lag in number of measurments

w_wave = zeros(1,ntime);

j = 0; 
l = 0;
% Actuating lag in wave velocity
while l < ntime  
     j = j + 1;
     l = j + floor(abs(nlag(j)));
     w_wave(l)  = wave(j);         
end
% Reduction in velocity due to depth
w_wave = exp(k*zf).*w_wave;

AoA_wave = w_wave./speed./deg2rad.*AmpS;

% Angle of attack prior to phase shift due to vessel motion
AoA_vsl = ((-eta3dot + eta5dot*xf)./speed - pitch)./deg2rad.*AmpC;

% Phase shift from Theodorsen - memory effects
time_phs = (PhsC)./w_e;
nlag     = -time_phs./dt;

AoA_tmp = zeros(1,ntime);

j = 0; 
l = 0;

% Actuating phase shift
while l < ntime    
     j = j + 1;
     l = j + floor(abs(nlag(j)));
     AoA_tmp(l)  = AoA_vsl(j);        
end

AoA = AoA_tmp + AoA_wave;

CL_relvel   = AoA*deg2rad*CL_foil;
CL_relvelNL = CLgen(AoA); 

CD_relvel   = 0.0005.*AoA.^2 + 0.015;

L = CL_relvel.*(0.5.*speed.^2.*rho.*S);
D = CD_relvel.*(0.5.*speed.^2.*rho.*S);

N_force = L.*cos(AoA*deg2rad) + D.*sin(AoA*deg2rad);
T_force = L.*sin(AoA*deg2rad) - D.*cos(AoA*deg2rad);

%% Estimates effective angle of attack and lift from pressure detection
% Cp defined from pressure experiments
% Cp51 = (p5-p1)/(0.5*U^2*rho)*1000 - made dimensionless in Pa
syms Cp x 

alpha   = solve('Cp = 0.0256*x - 0.0542');
p5minp1 = p5 - p1;
Cp51    = p5minp1./(0.5.*speed.^2.*rho).*1000;

% Finds alpha in any timestep from pressure, AoAp [deg]
AoAp = -subs(alpha,Cp,Cp51);         % Effective angle of attack
%CLp  =  CLgen(AoAp);                 % Runs CL-generator (static)
%Lp   =  CLp.*(0.5*U^2*rho*S);        % Instantaneous lift  

CLp_dyn   = AoAp*deg2rad*CL_foil;   % Dynamic linear estimate        
%Lp_dyn    = CLp_dyn*(0.5*U^2*rho*S); 

%% Estimates from AoA-estimate

CLp2_dyn   = aoaest*deg2rad*CL_foil;


figure(110)
hold on
plot(aoaest,'b')
plot(AoA,'r')
plot(AoAp,'g')
%plot(CL)
axis([30000 32000 -25 25])
title('Angle of attack')
legend('From pressure (Bockmann)',...
    'From rel. velocity',...
    'From pressure');
    xlabel('Time [s]');
    ylabel('Angle of attack'); 
hold off

% Defining one period oscillation
nstart  = 150;      % Start time
nend    = (nstart+2*T);

% figure(120)
% hold on
% title(strcat('Hysterisis-plot of CL vs AoA. Filename: ', path))
% scatter(AoA(nstart:nend),CL(nstart:nend),2.1,'k')
% legend('Angle of attack from rel.vel.');
% grid
% xlabel('Time [s]');
% ylabel('Degrees [deg]')
% hold off

figure(130)
hold on
plot(time,CL,'k');
plot(time,CL_relvel,'b');
plot(time,CL_relvelNL,'c');
plot(time,CLp_dyn,'r');
plot(time,CLp2_dyn,'g');
axis([nstart nend -2 2])
title('Lift coefficients')
legend('From force equil.',...
    'From relative velocity',...
    'From relative velocity (Non-lin CL)',...
    'From pressure',...
    'From pressure (Bockmann)');
    xlabel('Time [s]');
    ylabel('Lift coefficient [-]'); 
hold off

figure(140)
hold on
plot(time,lift,'r');
plot(time,N_force,'b');
axis([nstart nend -600 600])
title('Lift force')
legend('From force equil.',...
    'From relative velocity');
    xlabel('Time [s]');
    ylabel('Lift force [N]'); 
hold off

figure(150)
hold on
plot(time,thrust,'r');
plot(time,T_force,'b');
axis([nstart nend -20 120])
title('Thrust force')
legend('From force equil.',...
    'From relative velocity');
    xlabel('Time [s]');
    ylabel('Thrust force [N]'); 
hold off

nstart  = 150/dt;      % Start time
nend    = floor((nstart+8*T/dt));

mean(thrust(nstart:nend))

figure(200);
subplot(4,1,1)
plot(time,resistance); ylabel('resistance'); grid on
subplot(4,1,2)
plot(time,thrust); ylabel('thrust'); grid on
subplot(4,1,3)
plot(time,speed); ylabel('speed'); grid on
subplot(4,1,4)
plot(time,lift); ylabel('lift'); grid on

% figure(201);
% plot(CL); ylabel('CL'); grid on
% axis([0 ntime -2 2])


% Channel information (columns in A), set-up 1
% 1. DAQ time stamps
% 2. DAQ time stamps SR 2
% 3. DAQ time stamps SR 3
% 4. DAQ time stamps absolute
% 5. DAQ time stamps absolute SR 2
% 6. DAQ time stamps absolute SR 3
% 7. NTP time channel SR1
% 8. NTP time channel SR3
% 9. NTP time channel SR2
% 10. Xpos4
% 11. Ypos4
% 12. Zpos4
% 13. Roll4
% 14. Pitch4
% 15. Yaw4
% 16. Waveheight_1_u3
% 17. Pressure_6671
% 18. Pressure_6667
% 19. Pressure_6668
% 20. Pressure_6669
% 21. Pressure_6670
% 22. speed_carriage
% 23. Pitch
% 24. Z_pos_heave
% 25. Fin_angle
% 26. Force_wing_Sb
% 27. Force_wing_Ps
% 28. Force_wing_rear
% 29. Fx_tot
% 30. Towforce_Sb
% 31. Towforce_Ps
% 32. Wave2_carr
% 33. Towforce_tot
% 34. Lift_foil

% Channel information (columns in A), set-up 2
% 1. DAQ time stamps, length 5568
% 2. DAQ time stamps SR 2, length 44538
% 3. DAQ time stamps SR 3, length 0
% 4. DAQ time stamps absolute, length 5568
% 5. DAQ time stamps absolute SR 2, length 44538
% 6. DAQ time stamps absolute SR 3, length 0
% 7. NTP time channel SR1, length 5568
% 8. NTP time channel SR3, length 0
% 9. NTP time channel SR2, length 44538
% 10. Xpos4, length 5568
% 11. Y0pos4, length 5568
% 12. Zpos4, length 5568
% 13. Roll4, length 5568
% 14. Pitch4, length 5568
% 15. Yaw4, length 5568
% 16. Waveheight_1_u3, length 44538
% 17. Pressure_6671-2, length 44538
% 18. Pressure_6667-4, length 44538
% 19. Pressure_6668-1, length 44538
% 20. Pressure_6669-5, length 44538 
% 21. Pressure_6670-3, length 44538
% 22. speed_carriage, length 44538
% 23. Pitch, length 44538
% 24. Z_pos_heave, length 44538
% 25. Fin_angle, length 44538
% 26. Motor_angle, length 44538
% 27. AoA_est, length 44538
% 28. Phi, length 44538
% 29. Delta_paadrag, length 44538
% 30. Delta_opt, length 44538
% 31. AoA_opt, length 44538
% 32. Force_wing_Sb, length 44538
% 33. Force_wing_Ps, length 44538
% 34. Force_wing_rear, length 44538
% 35. Fx_tot, length 44538
% 36. Towforce_Sb, length 44538
% 37. Towforce_Ps, length 44538
% 38. Wave2_carr, length 44538
% 39. Towforce_tot, length 44538
% 40. Lift_foil, length 44538

% Channel information (columns in A), set-up 3
% 1. DAQ time stamps
% 2. DAQ time stamps SR 2
% 3. DAQ time stamps SR 3
% 4. DAQ time stamps absolute
% 5. DAQ time stamps absolute SR 2
% 6. DAQ time stamps absolute SR 3
% 7. NTP time channel SR1
% 8. NTP time channel SR3
% 9. NTP time channel SR2
% 10. Xpos4
% 11. Ypos4
% 12. Zpos4
% 13. Roll4
% 14. Pitch4
% 15. Yaw4
% 16. Waveheight_1_u3
% 17. speed_carriage
% 18. Towforce_Sb
% 19. Towforce_Ps
% 20. Wave2_carr
% 21. Towforce_tot




