function vessel = read_ABC(folder)

% Fridtjof Camillo Eitzen
% Created: 16.10.2011
% -------------
% Requirements: Retrieve hydrodynamics forces from input-file
% Design:
% Interface:
% Last edited: 16.10.2011
% -------------

% Opening file
fid = fopen([folder,'\input.re7'],'r');

% Retrieving file information
for d = 1:6; fgetl(fid); 
end

% Retrieving vessel parameters
read = fscanf(fid,'%f',7);
read = num2cell(read);
[rho g length width draught lcg vcg] = deal(read{:});

% Retrieving discarded information
for d =1:2; fgetl(fid); 
end

% Retrieving specter parameters
read = fscanf(fid,'%f',4);
read = num2cell(read);
[nvels nheads nfreqs ndof] = deal(read{:});

% Preallocating
vels                            = zeros(nvels, 1);
heads                           = zeros(nheads,1);
freqs                           = zeros(nfreqs,1);

% Retrieving a temporary mass matrix
M(:,:) = fscanf(fid,'%f',[ndof ndof])';
vessel.main.nabla  = M(1,1)/rho;
vessel.main.k44 = sqrt(M(4,4)/M(1,1));
vessel.main.k55 = sqrt(M(5,5)/M(1,1));
vessel.main.k66 = sqrt(M(6,6)/M(1,1));


% Retrieving velsocity parameters
for i = 1:nvels;
    % vels saves: velsocity, sinkage, trim, xmtn and zmtn
    % xmtn: x-position of motion coordinate axes
    % zmtn: z-position of motion coordinate axes
    temp    = fscanf(fid,'%f',5); 
    vels(i) = temp(1);
    
    % Retrieving headsing
    for j = 1:nheads;
        heads(j) = fscanf(fid,'%f',1);
        
        % Retrieving freqsuency
        for k = 1:nfreqs;
            freqs(k) = fscanf(fid,'%f',1);
            
            vessel.A(:,:,k,j,i)      = fscanf(fid,'%f',[ndof ndof])';
            vessel.AA(:,:,k,j,i)     = fscanf(fid,'%f',[ndof ndof])';
            vessel.B(:,:,k,j,i)      = fscanf(fid,'%f',[ndof ndof])';
            vessel.AB(:,:,k,j,i)     = fscanf(fid,'%f',[ndof ndof])';
            vessel.C(:,:,k,j,i)      = fscanf(fid,'%f',[ndof ndof])';
            vessel.AC(:,:,k,j,i)     = fscanf(fid,'%f',[ndof ndof])';
            vessel.Bv(k,:)           = fscanf(fid,'%f',3);
                  
        end
    end
end

vessel.main.rho = rho;
vessel.main.g   = g;
vessel.main.Lpp = length;
vessel.main.W   = width;
vessel.main.D   = draught;
vessel.main.lcg = lcg;
vessel.main.vcg = vcg;

vessel.velocities  = vels;
vessel.headings    = heads*pi/180;
vessel.freqs       = freqs;
vessel.ndof        = ndof;

vessel.M = M;



return