function vessel = read_motionRAO(folder)

% Fridtjof Camillo Eitzen
% Created: 14.02.2012
% -------------
% Requirements: Retrieve excitation forces from input-file
% Design:
% Interface:
% Last edited: 16.03.2012
% -------------

% Opening file
fid = fopen([folder,'\input.re1'],'r');

% Retrieving heading information
for d = 1:6; fgetl(fid); 
end

% Retrieving vessel parameters
read = fscanf(fid,'%f',7);
read = num2cell(read);
[rho g length width draught lcg vcg] = deal(read{:});

% Retrieving specter parameters
read = fscanf(fid,'%f',4);
read = num2cell(read);
[nvels nheads nfreqs ndof] = deal(read{:});

% Setting up matrices
vels    = zeros(nvels, 1);
heads   = zeros(nheads,1);
freqs   = zeros(nfreqs,1);

% Retrieving velocity parameters
for i = 1:nvels;
    % vel saves: velocity, sinkage, trim, xmtn and zmtn
    % xmtn: x-position of motion coordinate axes
    % zmtn: z-position of motion coordinate axes
    temp   = fscanf(fid,'%f',5); 
    vels(i) = temp(1);
    
    % Retrieving heading
    for j = 1:nheads;
        heads(j) = fscanf(fid,'%f',1);
        
        % Retrieving frequency
        for k = 1:nfreqs;
            freqs(k) = fscanf(fid,'%f',1);
            
            % Retrieving transfer function for all dof
            for l = 1:ndof;
                read = fscanf(fid,'%f',3); read = num2cell(read);
                [dof real img] = deal(read{:});
                motion = complex(real,img);
                
                vessel.motionRAO.complex(l,1,k,j,i) = motion;
                vessel.motionRAO.amp{l}(k,j,i)    = abs(motion);
                vessel.motionRAO.phase{l}(k,j,i)  = angle(motion);
                
                if dof ~= l; error('Input-file error');
                end
                
            end
        end
    end
end

vessel.main.rho = rho;
vessel.main.g   = g;
vessel.main.Lpp = length;
vessel.main.W   = width;
vessel.main.D   = draught;
vessel.main.lcg = lcg;
vessel.main.vcg = vcg;

vessel.velocities = vels;
vessel.headings   = heads*pi/180;
vessel.freqs      = freqs;

return