function vesselABC = struct2ss(vessel)

% Based on/copied from Fossen's MSS-kit

close all

%% ------------------------------------------------------------------------
% USER INPUTS
% -------------------------------------------------------------------------

% system identification options
FDIopt.OrdMax     = 20;
FDIopt.Method     = 2;
FDIopt.Iterations = 20;
FDIopt.LogLin     = 1;
FDIopt.wsFactor   = 0.1;
FDIopt.wminFactor = 0.1;
FDIopt.wmaxFactor = 5;
                                    
%--------------------------------------------------------------------------
%% COMPUTATIONS (do not edit below this line unless you know what you are doing)
% -------------------------------------------------------------------------
%--------------------------------------------------------------------------
%% Frequency-domain identification
%--------------------------------------------------------------------------
 % frequencies
Nf = length(vessel.freqs);
w  = vessel.freqs(1:Nf);   % does not include ininite frequency

% Indices for starboard-port symmetric vessels
% VERES (only element 1,1, in surge, no coupling)

idx_M = {1,2,2,2,3,3,4,4,5,6};
idx_N = {1,2,4,6,3,5,4,6,5,6};

% idx_M = {1,3,3,5};
% idx_N = {1,3,5,5};
%Complete 6x6 matrix
Ar{6,6} = 0;
Br{6,6} = 0;
Cr{6,6} = 0;
Dr{6,6} = 0;

Ainf = zeros(6);
C    = vessel.C(:,:,1);
M  = vessel.M;
  
for i = 1:length(idx_M),
    
    dof =[idx_M{i},idx_N{i}];   % 12 elements due to starboard-port symmetry
    
    % hydrodynamic raw data
    A    = reshape( vessel.A(dof(1),dof(2),1:Nf),1,Nf)';
    B    = reshape( vessel.B(dof(1),dof(2),1:Nf),1,Nf)';  
      
    % Call FDIRadMod (Matlab tool for frequency identification)    
    FDIopt.AinfFlag = 0;
    [Krad,Ainf_hat] = FDIRadMod(w,A,0,B,FDIopt,dof);
    
    Ainf(dof(1),dof(2)) = Ainf_hat; % estimated infinite added mass matrix

    % compute state-space model (Ar,Br,Cr)
    if sum(vessel.A(dof(1),dof(2),:)) == 0
        Arad = 0;
        Brad = 0;
        Crad = 0;
    else
        [Arad,Brad,Crad,~] = tf2ss(Krad.num{1},Krad.den{1});
    end
    
    
    Ar{dof(1),dof(2)} = Arad;
    Br{dof(1),dof(2)} = Brad;
    Cr{dof(1),dof(2)} = Crad;
    Dr{dof(1),dof(2)} = 0;

end

% Symmetric elements
Ar{3,1} = Ar{1,3};
Br{3,1} = Br{1,3};
Cr{3,1} = Cr{1,3};
Dr{3,1} = Dr{1,3};
Ainf(3,1) = Ainf(1,3);

Ar{4,2} = Ar{2,4};
Br{4,2} = Br{2,4};
Cr{4,2} = Cr{2,4};
Dr{4,2} = Dr{2,4};
Ainf(4,2) = Ainf(2,4);

Ar{5,1} = Ar{1,5};
Br{5,1} = Br{1,5};
Cr{5,1} = Cr{1,5};
Dr{5,1} = Dr{1,5};
Ainf(5,1) = Ainf(1,5);

Ar{5,3} = Ar{3,5};
Br{5,3} = Br{3,5};
Cr{5,3} = Cr{3,5};
Dr{5,3} = Dr{3,5};
Ainf(5,3) = Ainf(3,5);

Ar{6,2} = Ar{2,6};
Br{6,2} = Br{2,6};
Cr{6,2} = Cr{2,6};
Dr{6,2} = Dr{2,6};
Ainf(6,2) = Ainf(2,6);

Ar{6,4} = Ar{4,6};
Br{6,4} = Br{4,6};
Cr{6,4} = Cr{4,6};
Dr{6,4} = Dr{4,6};
Ainf(6,4) = Ainf(4,6);







%--------------------------------------------------------------------------
%% Save data
% -------------------------------------------------------------------------
vesselABC.Ar        = Ar;
vesselABC.Br        = Br;
vesselABC.Cr        = Cr;
vesselABC.Dr        = Dr;

vesselABC.C         = C;
vesselABC.Ainf      = Ainf;
vesselABC.M       = M;


