function T  = thrust(foil,vessel)

% Script based on Thomas Borges' MSc Thesis

xf = foil.main.xf;
yf = foil.main.yf;
zf = foil.main.zf;
cord = foil.main.cord;
span = foil.main.span;

g       = foil.main.g;
rho     = foil.main.rho;
rad2deg = 180/pi;

% Finding CL
foil = foilChar(foil);
dCL = foil.main.CL;

% Finding CD
CD2  = 0.0005/2;
CD0  = 0.015/2;

freqs   = vessel.freqs;
vels    = vessel.velocities;
heads   = vessel.headings;

nfreqs  = length(freqs);
nvels   = length(vels);
nheads  = length(heads);

[T] = deal(zeros(nfreqs,nheads,nvels));
%freqs_e = zeros(1,nfreqs);

for i = 1:nvels;
    
    U = vels(i);
        
    for j = 1:nheads;
        
        Beta = heads(j);
        
        for h = 1:nfreqs;
            
            w   = freqs(h);
            k   = w^2/g;
            w_e = w + k*cos(Beta)*U;
            T_e = 2*pi/w_e;
            
            % Finding index of encounter frequency
            % [~,idx] = min(freqs-w_e);
            % freqs_e(h) = w_e;
            
            C = theodorsen(cord,U,w_e);
            ampC = abs(C);
            phsC = angle(C);
                        
            % Wave velocity RAO at foil
            waveRAO = 1i*w*exp(k*zf)*exp(-1i*k*(xf*cos(Beta)+yf*sin(Beta)));
            
            % Retrieving RAO's for encounter frequency for vessel w foil
            eta3RAO = vessel.motionRAO.complex(3,1,h,j,i);
            %eta4RAO = vessel.motionRAO.complex(4,h,j,i);
            eta5RAO = vessel.motionRAO.complex(5,1,h,j,i);
            
            syms t
            
            eta3 = abs(eta3RAO)*cos(w_e*t + angle(eta3RAO) + phsC);
            eta5 = abs(eta5RAO)*cos(w_e*t + angle(eta5RAO) + phsC);
            wave = abs(waveRAO)*cos(w_e*t + angle(waveRAO) + phsC);
            
            eta3dot = diff(eta3);
            eta5dot = diff(eta5);
            
            phi = (wave-eta3dot+xf*eta5dot)/U;
            AoA = (phi + eta5)*ampC;           
            
            % Time averaging
            angL = subs(int(AoA*phi,t,0,T_e))/T_e;
            angD = subs(int((AoA*rad2deg)^2,t,0,T_e))/T_e;
            
            dF = 0.5*rho*U^2*cord*span;
            
            L = dF*dCL*angL;
            D = dF*(CD2*angD + CD0);
            
            T(h,j,i) = L - D;
            
                           
        end
    end
end










