

freqs  = ship.freqs;
heads  = ship.headings;
vels   = ship.velocities;

nfreqs = length(freqs);
nheads = length(heads);
nvels  = length(vels);
ndof   = ship.ndof;

g    = ship.main.g;
rho  = ship.main.rho;

xf   = foil.main.xf;
yf   = foil.main.yf;
zf   = foil.main.zf;
span = foil.main.span;
cord = foil.main.cord;

foil = foilChar(foil);

CL = 2*pi/(1+2/(span/cord));
[CL_mat,AoA] = CLgen; % Runs script - CL matrix

r = [xf,yf,zf]';
[Hss,H,amp] = deal(zeros(ndof,nfreqs,nheads,nvels));
Thrust      = deal(zeros(nfreqs,nheads,nvels));
eigplot     = zeros(2*ndof,1);

for h = 1:nvels;
    %h = 2;
    U = vels(h);
    
    for j = 1:nheads;
        %j = 1;
        for i = 7:nfreqs;
            %i = 23;

            foil = fitTheodorsen(foil,ship,U);

            foil.main.xCO = 0;%cord/8;%cord/8;%0;%cord;
            foil.main.xLO = 1;%0;%-cord/8;

            wn0  = 1.31;
            xi0  = 1;

            %foil = foilControl(foil,U,wn0,xi0);
            foil.control.Kp = 0;%50e6;
            foil.control.Ki = 0;%60e6;
            foil.control.Kd = 0;%10e4;

            a_h  = ship.A(:,:,i,j,h);
            b_h  = ship.B(:,:,i,j,h);
            c_h  = ship.C(:,:,i,j,h);
            f_hw = ship.forceRAO.complex(:,:,i,j,h);

            a_f   = foil.A(:,:,i,j,h);
            b_f   = foil.B(:,:,i,j,h);
            c_f   = foil.C(:,:,i,j,h);
            f_fw  = foil.F(:,:,i,j,h);
            f_fd  = foil.Fd(:,:,i,j,h);
            f_fdi = foil.F_di(:,:,i,j,h);
            f_fun = foil.F_un(:,:,i,j,h);


            wave = foil.Wave(i,j,h);

            m  = ship.M;
            a  = a_h + a_f;
            b  = b_h + b_f;
            c  = c_h + c_f;
            f  = f_hw + f_fdi + f_fun;

            minv = inv(m+a);

            psi_a = 1;

            w    = freqs(i);
            Beta = heads(j);

            k    = w^2/g;
            w_e  = w + k*U*cos(Beta);

            % State space representation
            % ------------------------------------------------------------
            Ass = [zeros(ndof) eye(ndof);
                   -(m+a)\c   -(m+a)\b ]; 
            Bss = [zeros(ndof,1);
                      (m+a)\f  ];
            Css = [eye(ndof) zeros(ndof)];                 
            Dss = 0;


            % State-space system and transfer function
            SSsys = ss(Ass,Bss,Css,Dss);        
            TFsys = tf(SSsys);
            eigen = eig(Ass);

            %eigplot(:,:,i,h,j)=[real(eigen) imag(eigen)];

            %Simulink representation
            %-------------------------------------------------------------
            sim(model);

            heave_amp  = sqrt(2)*std(heavedisp.signals.values)/psi_a;
            pitch_amp  = sqrt(2)*std(pitchdisp.signals.values);
            thrust_avg = mean(thrustforce.signals.values);

            % Frequency-response vector
            Hss(:,i,j,h)  = freqresp(TFsys,w_e);
            % Mean thrust-force
            Thrust(i,j,h) = thrust_avg;
            

            % Fourier transfer function 
            % -------------------------------------------------------------
            % Encounter frequency as input - wave frequency as x-axis

            H(:,i,j,h) = (-(m+a)*w_e^2 + b*1i*w_e + c)\f;

            figure(1+h)
            ms2kn = 1/0.5144;
            hold on
            
            plot(freqs,ship.motionRAO.amp{3}(:,j,h));
            plot(w,abs(Hss(3,i,j,h)),'r*');
            plot(w,abs(H(3,i,j,h)),'gd');
            plot(w,heave_amp,'*k');
            
            title(strcat('Response amplitude in Heave at ',num2str(U*ms2kn),' knots'))
            xlabel('Wave frequency [1/s]')
            ylabel('RAO [-]')
            legend('From VERES',...
                'From State-space',...
                'From freq. domain',...
                'From time-domain');
            
            hold off
            
            figure(10+h)
            hold on
            
            plot(freqs,ship.motionRAO.amp{5}(:,j,h));
            plot(w,abs(Hss(5,i,j,h)),'r*');
            plot(w,abs(H(5,i,j,h)),'gd');
            plot(w,pitch_amp,'*k');
            
            title(strcat('Response amplitude in Pitch at ',num2str(U*ms2kn),' knots'))
            xlabel('Wave frequency [1/s]')
            ylabel('RAO [-]')
            legend('From VERES',...
                'From State-space',...
                'From freq. domain',...
                'From time-domain');
            
            hold off

        end
    end
end

% Thomas Borgen Thrust model
%T_Borgen = thrust(foil,ship);

% figure(20)
% hold on
%             
% plot(freqs,Thrust(:,1,1),'k',freqs,Thrust(:,1,2),'*-k',freqs,Thrust(:,1,3),'+-k');
% plot(freqs,T_Borgen(:,1,1),'o--b',freqs,T_Borgen(:,1,2),'*--b',freqs,T_Borgen(:,1,3),'+--b');
% 
% title(strcat('Thrust at ',num2str(U*ms2kn),' knots'))
% xlabel('Wave frequency [1/s]')
% ylabel('Thrust force [N]')
% legend('8 kn',...
%     '10 kn',...
%     '12 kn');
% 
% hold off
















